Convenience functions for constructing shell commands
-----------------------------------------------------

Functions for safely constructing shell command lines from bare strings.
Somewhat like the inverse of the shlex stdlib module.
